@@ -17,8 +17,8 @@ def rings(features_X, features_position, criteria="k", max_radios=[200, 300, 400
     # Verificar que ambas listas sean de largo igual
     assert len(max_radios) == len(max_neighbours)
 
-    pts = np.array(list(zip(features_position.lon, features_position.lat)))
-    tree = spatial.KDTree(data=pts, leafsize=leafsize)
+    points = list(zip(features_position.lon, features_position.lat))
+    tree = spatial.KDTree(data=points, leafsize=leafsize)
     final_features_df = pd.DataFrame()
 
     if keep_original_value:
@@ -53,9 +53,9 @@ def rings(features_X, features_position, criteria="k", max_radios=[200, 300, 400
             nearest_neighbours = tree.query_ball_tree(tree, r)
             for j, neighbourhood in enumerate(nearest_neighbours): # Para cada punto
                 neighbourhood = np.array(neighbourhood) # Saco los vecinos dentro del radio r
-                temporal_tree = spatial.KDTree(data=pts[neighbourhood], leafsize=leafsize)
+                temporal_tree = spatial.KDTree(data=points[neighbourhood], leafsize=leafsize)
                 k_length = min(k, len(neighbourhood)) # Conseguir los K puntos más cercanos dentro de ese radio
-                distances, nearby_points = temporal_tree.query(pts[j], k = k_length)
+                distances, nearby_points = temporal_tree.query(points[j], k = k_length)
                 distances += smoothing # Tal vez simplemente eliminar el primer elemento que es el punto mismo
                 if(normalize):
                     distances = distances/np.linalg.norm(distances)
